@@ -81,13 +81,13 @@ fn main() {
     // we may override format for error messages
     let mut format_str = openweathermap::LOADING.to_string();
     // remember visibility from weather report for ISS spotting
-    let mut visibility: Visibility = Visibility::INVISIBLE;
+    let mut visible: bool = false;
     // remember daytime from weather report for ISS spotting
     let mut daytime: DayTime;
     let mut dt: Option<&DayTime> = None;
     // remember duration of current spotting event in milliseconds for motification timeout
     let mut duration = Duration::from_millis(0);
-    // create notification state
+    // state of current notification
     let mut notify = Notify::new(notify);
     // create blinking flag
     let mut blinking: bool = false;
@@ -101,7 +101,7 @@ fn main() {
             Some(response) => match response {
                 Ok(w) => {
                     // remember cloudiness for spotting visibility
-                    visibility = Visibility::from_bool(w.clouds.all <= max_cloudiness as f64);
+                    visible = w.clouds.all <= max_cloudiness as f64;
                     // remember daytime from current weather if wanted
                     if !dayspot {
                         daytime = DayTime::from_utc(w.sys.sunrise, w.sys.sunset);
@@ -150,11 +150,12 @@ fn main() {
             &mut props,
             &spottings,
             soon,
-            &visibility,
+            visible,
             dt,
             blinking,
             &level,
         );
+        // check if we shall generate a notification
         notify.notification(duration, level);
         // toggle blinking flag
         if blink {
@@ -174,7 +175,7 @@ fn main() {
 /// insert properties into format string
 /// #### Parameters
 /// - `format`: output format (string including some of the available keys)
-/// - `props`: property map to add data into
+/// - `props`: property map to get data to insert from
 /// #### Return value
 /// - formatted string
 fn format_string(format: &str, props: &HashMap<&str, String>) -> String {
